@@ -1,4 +1,4 @@
-from .integration import add_auth
+from .add import add_auth
 
 __all__ = [
     "add_auth",
