@@ -1,14 +1,13 @@
 from __future__ import annotations
 
-from fastapi import APIRouter
-
+from svc_infra.api.fastapi import DualAPIRouter
 from svc_infra.db.nosql.mongo.client import ping_mongo
 
 
 def make_mongo_health_router(
     *, prefix: str = "/_mongo/health", include_in_schema: bool = False
-) -> APIRouter:
-    router = APIRouter(prefix=prefix, include_in_schema=include_in_schema)
+) -> DualAPIRouter:
+    router = DualAPIRouter(prefix=prefix, include_in_schema=include_in_schema)
 
     @router.get("")
     async def healthcheck():
