@@ -9,7 +9,9 @@ from fastapi_users.authentication import AuthenticationBackend, BearerTransport,
 from fastapi_users.manager import BaseUserManager, UUIDIDMixin
 
 from svc_infra.api.fastapi import DualAPIRouter, dualize_router
-from svc_infra.auth.settings import get_auth_settings
+from svc_infra.api.fastapi.auth.settings import get_auth_settings
+
+from .session import SqlSessionDep
 
 
 def get_fastapi_users(
@@ -26,7 +28,7 @@ def get_fastapi_users(
     # Lazy import to avoid hard dependency at module import time
     from fastapi_users_db_sqlalchemy import SQLAlchemyUserDatabase
 
-    async def get_user_db(session) -> AsyncIterator[Any]:
+    async def get_user_db(session: SqlSessionDep) -> AsyncIterator[Any]:
         yield SQLAlchemyUserDatabase(session, user_model)
 
     class UserManager(UUIDIDMixin, BaseUserManager[Any, UUID]):
@@ -37,11 +39,28 @@ def get_fastapi_users(
         yield UserManager(user_db)
 
     def get_jwt_strategy() -> JWTStrategy:
+        """
+        Support nested settings:
+          settings.jwt.secret (SecretStr)
+          settings.jwt.lifetime_seconds (int)
+
+        Falls back to safe dev defaults if unset (only for local/test).
+        """
         settings = get_auth_settings()
-        return JWTStrategy(
-            secret=settings.jwt_secret.get_secret_value(),
-            lifetime_seconds=settings.jwt_lifetime_seconds,
-        )
+
+        # Nested fields: settings.jwt.secret, settings.jwt.lifetime_seconds
+        jwt_block = getattr(settings, "jwt", None)
+        if jwt_block and getattr(jwt_block, "secret", None):
+            secret = jwt_block.secret.get_secret_value()
+        else:
+            # dev/test fallback to avoid crashes; DO NOT use in prod
+            secret = "svc-dev-secret-change-me"
+
+        lifetime = getattr(jwt_block, "lifetime_seconds", None) if jwt_block else None
+        if not isinstance(lifetime, int) or lifetime <= 0:
+            lifetime = 3600  # 1 hour default
+
+        return JWTStrategy(secret=secret, lifetime_seconds=lifetime)
 
     bearer_transport = BearerTransport(tokenUrl=f"{auth_prefix}/jwt/login")
     auth_backend = AuthenticationBackend(
